==> brlcad-7.24.2.tar.bz2: brlcad-7.24.2/src/conv/step/step-g/PlaneAngleContextDependentUnit.h <==
/*                 PlaneAngleContextDependentUnit.h
 * BRL-CAD
 *
 * Copyright (c) 1994-2013 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this file; see the file named COPYING for more
 * information.
 */
/** @file step/PlaneAngleContextDependentUnit.h
 *
 * Class definition used to convert STEP "PlaneAngleContextDependentUnit" to BRL-CAD BREP
 * structures.
 *
 */

#ifndef PLANEANGLECONTEXTDEPENDENTUNIT_H_
#define PLANEANGLECONTEXTDEPENDENTUNIT_H_

#include "PlaneAngleUnit.h"
#include "ContextDependentUnit.h"

class PlaneAngleContextDependentUnit : public PlaneAngleUnit, public ContextDependentUnit
{
private:
    static string entityname;
    static EntityInstanceFunc GetInstance;

protected:

public:
    PlaneAngleContextDependentUnit();
    virtual ~PlaneAngleContextDependentUnit();
    PlaneAngleContextDependentUnit(STEPWrapper *sw, int step_id);
    bool Load(STEPWrapper *sw, SDAI_Application_instance *sse);
    virtual void Print(int level);

    //static methods
    static STEPEntity *Create(STEPWrapper *sw, SDAI_Application_instance *sse);
};

#endif /* PLANEANGLECONTEXTDEPENDENTUNIT_H_ */

/*
 * Local Variables:
 * tab-width: 8
 * mode: C
 * indent-tabs-mode: t
 * c-file-style: "stroustrup"
 * End:
 * ex: shiftwidth=4 tabstop=8
 */

==> brlcad-7.32.4.tar.bz2: brlcad-7.32.4/src/conv/step/step-g/PlaneAngleContextDependentUnit.h <==
/*                 PlaneAngleContextDependentUnit.h
 * BRL-CAD
 *
 * Copyright (c) 1994-2021 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this file; see the file named COPYING for more
 * information.
 */
/** @file step/PlaneAngleContextDependentUnit.h
 *
 * Class definition used to convert STEP "PlaneAngleContextDependentUnit" to BRL-CAD BREP
 * structures.
 *
 */

#ifndef CONV_STEP_STEP_G_PLANEANGLECONTEXTDEPENDENTUNIT_H
#define CONV_STEP_STEP_G_PLANEANGLECONTEXTDEPENDENTUNIT_H

#include "PlaneAngleUnit.h"
#include "ContextDependentUnit.h"

class PlaneAngleContextDependentUnit : public PlaneAngleUnit, public ContextDependentUnit
{
private:
    static string entityname;
    static EntityInstanceFunc GetInstance;

protected:

public:
    PlaneAngleContextDependentUnit();
    virtual ~PlaneAngleContextDependentUnit();
    PlaneAngleContextDependentUnit(STEPWrapper *sw, int step_id);
    bool Load(STEPWrapper *sw, SDAI_Application_instance *sse);
    virtual void Print(int level);

    //static methods
    static STEPEntity *Create(STEPWrapper *sw, SDAI_Application_instance *sse);
};

#endif /* CONV_STEP_STEP_G_PLANEANGLECONTEXTDEPENDENTUNIT_H */

/*
 * Local Variables:
 * tab-width: 8
 * mode: C
 * indent-tabs-mode: t
 * c-file-style: "stroustrup"
 * End:
 * ex: shiftwidth=4 tabstop=8
 */
